pub enum Operation {
Eq(Operand),
Lt(Operand),
Lte(Operand),
Gt(Operand),
Gte(Operand),
Contains(String),
Exists,
}Expand description
Variants
Eq(Operand)
Check if the value for the key is equal to this operand
Lt(Operand)
Check if the value for the key is less than this operand
Lte(Operand)
Check if the value for the key is less than or equal to this operand
Gt(Operand)
Check if the value for the key is greater than this operand
Gte(Operand)
Check if the value for the key is greater than or equal to this operand
Contains(String)
Check if the value for the key contains a certain sub-string
Exists
Check if the key exists